@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.18 2000/05/11 09:03:45 fredgo Exp $
+# $Id: Editor.py,v 1.18.2.3 2000/08/03 11:29:32 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -464,6 +464,8 @@ class RealEditor (Connector.Publisher):
         self.newfield_area = GtkHBox (spacing = 5)
         self.newfield_area.set_border_width (5)
         self.newfield = GnomeEntry ('newfield')
+        self.newfield.load_history ()
+        
         self.newfield_area.pack_start (self.newfield)
 
         b = GtkButton (_("Create Field"))
@@ -474,11 +476,14 @@ class RealEditor (Connector.Publisher):
         self.w.pack_start (self.newfield_area, FALSE, FALSE)
         
         # Notebook
+        scroll = GtkScrolledWindow ()
+        scroll.set_policy (GTK.POLICY_AUTOMATIC, GTK.POLICY_AUTOMATIC)
         self.notebook = GtkNotebook ()
         self.notebook.show ()
 
-        self.w.pack_start (self.notebook)
-        self.w.show ()
+        scroll.add_with_viewport (self.notebook)
+        self.w.pack_start (scroll)
+        self.w.show_all ()
         
         self.notebook_init = FALSE
         self.update_notebook ()
@@ -572,9 +577,12 @@ class RealEditor (Connector.Publisher):
 
     def create_field (self, * arg):
         widget = self.newfield.gtk_entry ()
-        text = string.strip (string.lower (widget.get_text ()))
+        text   = string.strip (string.lower (widget.get_text ()))
         if text == '': return
 
+        # update the current entry
+        self.entry = self.update (self.database, copy.deepcopy (self.entry))
+
         newtype = Types.get_field (text).type
         self.entry [text] = newtype (_newcontent [newtype])
         self.update_notebook ()
